#!/bin/bash

mypath="$(cd "`dirname "$0"`" ; pwd)"
scriptloc="$(readlink -f "$0")"

# Test for python
PYTHON="$mypath/python2.7-static"
pythonver=$($PYTHON --version 2>&1 | awk '{print $2}')
if [ ${pythonver:0:1} != "2" ]; then
	PYTHON=$(which python2)
	pythonver=$($PYTHON --version 2>&1 | awk '{print $2}')
	if [ ${pythonver:0:1} != "2" ]; then
		echo "Cannot find Python version 2" > /dev/stderr
		exit 1
	fi
fi

# Check for update
if [ -f "$mypath/update.tgz" ]; then
	echo "Updating..."
	tar -xzf "$mypath/update.tgz" -C "$mypath"
	rm "$mypath/update.tgz"
	touch "$mypath/.updated"
	exec $scriptloc $@
	exit 0
fi

# Check if app has just been updated
if [ -f "$mypath/.updated" ]; then
	echo "Updated to version $(cat "$mypath/VERSION")"
	rm "$mypath/.updated"
fi

# Check if machine architecture is 64 bit
export DOSEMU_ARCH=32
if [ "$(uname -m)" == "x86_64" ]; then
	# Give hint to the launcher to use 64 version of dosemu
	export DOSEMU_ARCH=64
fi

$PYTHON "$mypath/app/run.py" $@
