#!/bin/bash

mypath="$(cd "`dirname "$0"`" ; pwd)"

usage () {
	prog=$1
	echo "Usage: $prog [-f] [-u <URL>] [-h]"
	echo
	echo "   -f: force update"
	echo "   -u <URL>: use custom URL"
	echo "   -h: show this help"
}

FORCED=N
USR_REPOURL=
while getopts ':fu:h' opt; do
	case $opt in
		f)
			FORCED=Y
			;;
		u)
			USR_REPOURL="$OPTARG"
			;;
		h)
			usage $(basename $0) > /dev/stderr
			exit 0
			;;
		\?)
			echo "Unknown option: $OPTARG" > /dev/stderr
			;;
	esac
done

DEF_REPOURL="http://repo.pti-cosmetics.com/korporat/pkgs"
REPOURL="$(cat "$mypath/REPOURL")"
if [ -z "$REPOURL" ]; then
	REPOURL="$DEF_REPOURL"
fi
if [ ! -z "$USR_REPOURL" ]; then
	REPOURL="$USR_REPOURL"
fi

WGET=$(which wget)

current_version=$(cat "$mypath/VERSION")
repo_version=$($WGET -q -O- $REPOURL/korporat.VERSION)

if [ -z "$repo_version" ]; then
	echo "Tidak dapat mendapatkan informasi dari server. Cek koneksi internet"
	exit 1
fi

if [ "$FORCED" == "Y" -o "$current_version" != "$repo_version" ]; then
	wget -O"$mypath/update.tgz" "$REPOURL/korporat-$repo_version.tgz"
	if [ $? -eq 0 ]; then
		# CHECKSUM
		md5=$($WGET -q -O- $REPOURL/korporat-$repo_version.md5sum)
		if [ -z "$md5" ]; then
			echo "Gagal mendapatkan checksum"
			rm -f "$mypath/update.tgz"
			exit 2
		fi
		dlmd5=$(md5sum "$mypath/update.tgz" | awk '{print $1}')
		if [ "x$md5" != "x$dlmd5" ]; then
			echo "Validasi checksum gagal. Ulangi proses update"
			rm -f "$mypath/update.tgz"
			exit 3
		fi
		
		echo "Update selesai. Versi baru di-install: $repo_version"
	else
		echo "Update gagal. Pastikan koneksi internet dalam keadaan baik."
		rm -f "$mypath/update.tgz"
		exit 2
	fi
else
	echo "Update selesai. Program sudah up-to-date: $(cat "$mypath/VERSION")"
fi
